@@ -124,6 +124,7 @@ evolution <- function(x,xlim=NA,ylim=NA,alpha=0.05,transform=FALSE,
         if (isochron){
             fit <- isochron.ThU(x,type=3,plot=FALSE,
                                 exterr=exterr,model=model)
+            fit$n <- length(x)
             graphics::title(evolution.title(fit,sigdig=sigdig))
         }
     } else {
@@ -270,20 +271,26 @@ evolution.title <- function(fit,sigdig=2){
     expr1 <- quote('isochron age =')
     list1 <- list(a=rounded.age[1],
                   b=rounded.age[2],
-                  c=rounded.age[3])
+                  c=rounded.age[3],
+                  n=fit$n)
     expr2 <- quote('('^234*'U/'^238*'U)'[o]*~'=')
     list2 <- list(a=rounded.a0[1],
                   b=rounded.a0[2],
                   c=rounded.a0[3])
-    args <- quote(~a%+-%b~'|'~c)
-    call1 <- substitute(e~a,list(e=expr1,a=args))
-    line1 <- do.call(substitute,list(eval(call1),list1))
-    call2 <- substitute(e~a,list(e=expr2,a=args))
-    line2 <- do.call(substitute,list(eval(call2),list2))
     if (fit$model==1 && fit$mswd>1){
-        args <- quote(~a%+-%b~'|'~c~'|'~d)
+        args1 <- quote(~a%+-%b~'|'~c~'|'~d~'ka'~'(n='~n~')')
+        args2 <- quote(~a%+-%b~'|'~c~'|'~d)
         list1$d <- rounded.age[4]
         list2$d <- rounded.a0[4]
+    } else {
+        args1 <- quote(~a%+-%b~'|'~c~'ka')
+        args2 <- quote(~a%+-%b~'|'~c)
+    }
+    call1 <- substitute(e~a,list(e=expr1,a=args1))
+    line1 <- do.call(substitute,list(eval(call1),list1))
+    call2 <- substitute(e~a,list(e=expr2,a=args2))
+    line2 <- do.call(substitute,list(eval(call2),list2))
+    if (fit$model==1 && fit$mswd>1){
         line3 <- substitute('MSWD ='~a~', p('~chi^2*')='~b,
                             list(a=signif(fit$mswd,2),
                                  b=signif(fit$p.value,2)))
@@ -294,10 +301,10 @@ evolution.title <- function(fit,sigdig=2){
         graphics::mtext(line1,line=1)
         graphics::mtext(line2,line=0)
     } else if (fit$model==3) {
-        rounded.disp <- signif(fit$w,sigdig)
-        list3 <- list(a=rounded.disp[1],b=rounded.disp[2])
+        rounded.disp <- roundit(fit$w[1],fit$w[2:3],sigdig=sigdig)
         expr3 <- quote('('^232*'Th/'^238*'U)'-dispersion~'=')
-        args3 <- quote(a~'|'~b)
+        args3 <- quote(a+b-c)
+        list3 <- list(a=rounded.disp[1],b=rounded.disp[3],c=rounded.disp[2])
         call3 <- substitute(e~a,list(e=expr3,a=args3))
         line3 <- do.call(substitute,list(eval(call3),list3))
         graphics::mtext(line1,line=2)
