@@ -113,6 +113,9 @@
 #'     be used. If \code{levels} is a vector of numbers, then
 #'     \code{ellipse.col} is used to construct a colour ramp.
 #'
+#' @param ci.col the fill colour for the confidence interval of the
+#'     intercept and slope.
+#'
 #' @param line.col colour of the isochron line
 #'
 #' @param lwd line width
@@ -169,17 +172,19 @@ isochron <- function(x,...){ UseMethod("isochron",x) }
 isochron.default <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                              show.numbers=FALSE,levels=NA,clabel="",
                              ellipse.col=c("#00FF0080","#FF000080"),
-                             line.col='red',lwd=2,title=TRUE,model=1,...){
+                             ci.col='gray80',line.col='black',lwd=1,
+                             title=TRUE,model=1,...){
     X <- subset(x,select=1:5)
     colnames(X) <- c('X','sX','Y','sY','rXY')
-    fit <- regression(X,model=model)
-    out <- regression_init(fit,alpha=alpha)
+    fit <- regression_init(X,model=model,alpha=alpha)
+    fit <- ci_isochron(fit,model=model,alpha=alpha)
     scatterplot(X,xlim=xlim,ylim=ylim,alpha=alpha,
                 show.ellipses=1*(model!=2),show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
-                a=fit$a[1], b=fit$b[1],line.col=line.col,lwd=lwd)
+                fit=fit,ci.col=ci.col,line.col=line.col,lwd=lwd)
     if (title)
-        graphics::title(isochrontitle(out,sigdig=sigdig),xlab='X',ylab='Y')
+        graphics::title(isochrontitle(fit,sigdig=sigdig),
+                        xlab='X',ylab='Y')
 }
 #' @param plot if \code{FALSE}, suppresses the graphical output
 #'
@@ -247,20 +252,17 @@ isochron.default <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
 #' interval for \code{t} enhanced by \eqn{\sqrt{mswd}} (only
 #' applicable if \code{ model=1}).  }
 #'
-#' \item{tfact}{the \eqn{100(1-\alpha/2)\%} percentile of a
-#' t-distribution with \code{df} degrees of freedom.}
-#'
 #' \item{mswd}{the mean square of the residuals (a.k.a `reduced
 #'     Chi-square') statistic (omitted if \code{model=2}).}
 #'
 #' \item{p.value}{the p-value of a Chi-square test for linearity
 #' (omitted if \code{model=2})}
 #'
-#' \item{w}{the overdispersion term, i.e. a two-element vector with
+#' \item{w}{the overdispersion term, i.e. a three-element vector with
 #' the standard deviation of the (assumedly) Normally distributed
-#' geological scatter that underlies the measurements, and the
-#' corresponding studentised \eqn{100(1-\alpha)\%} confidence interval
-#' (only returned if \code{model=3}).}
+#' geological scatter that underlies the measurements, and the lower
+#' and upper half-widths of its \eqn{100(1-\alpha)\%} confidence
+#' interval (only returned if \code{model=3}).}
 #'
 #' }
 #'
@@ -330,11 +332,11 @@ isochron.default <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
 #' interval for \code{t} enhanced by \eqn{\sqrt{mswd}} (only reported
 #' if \code{model=1}).}
 #'
-#' \item{w}{the overdispersion term, i.e. a two-element vector with
+#' \item{w}{the overdispersion term, i.e. a three-element vector with
 #' the standard deviation of the (assumedly) Normally distributed
-#' geological scatter that underlies the measurements, and the
-#' corresponding \eqn{100(1-\alpha)\%} confidence interval (only
-#' returned if \code{model=3}).}
+#' geological scatter that underlies the measurements, and the lower
+#' and upper half-width of its \eqn{100(1-\alpha)\%} confidence
+#' interval (only returned if \code{model=3}).}
 #'
 #' \item{d}{a matrix with the following columns: the X-variable for
 #' the isochron plot, the analytical uncertainty of X, the Y-variable
@@ -360,46 +362,45 @@ isochron.default <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
 isochron.ArAr <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
-                          inverse=TRUE,line.col='red',lwd=2,plot=TRUE,
-                          exterr=TRUE,model=1,...){
-    d <- data2york(x,inverse=inverse)
-    fit <- regression(d,model=model)
-    out <- isochron_init(fit,alpha=alpha)
-    a <- fit$a['a']
-    sa <- fit$a['s[a]']
-    b <- fit$b['b']
-    sb <- fit$b['s[b]']
+                          inverse=TRUE,ci.col='gray80',line.col='black',
+                          lwd=1,plot=TRUE,exterr=TRUE,model=1,...){
+    out <- isochron_init(x,model=model,inverse=inverse,alpha=alpha)
+    a <- out$a['a']
+    sa <- out$a['s[a]']
+    b <- out$b['b']
+    sb <- out$b['s[b]']
     if (inverse) {
         R09 <- -b/a
-        sR09 <- R09*sqrt((sa/a)^2+(sb/b)^2-2*sa*sb*fit$cov.ab)
+        sR09 <- R09*sqrt((sa/a)^2+(sb/b)^2-2*sa*sb*out$cov.ab)
         out$y0['y'] <- 1/a
         out$y0['s[y]'] <- sa/a^2
-        x.lab <- expression(paste(""^"39","Ar/"^"40","Ar"))
-        y.lab <- expression(paste(""^"36","Ar/"^"40","Ar"))
+        x.lab <- quote(''^39*'Ar/'^40*'Ar')
+        y.lab <- quote(''^36*'Ar/'^40*'Ar')
     } else {
         R09 <- b
         sR09 <- sb
         out$y0['y'] <- a
         out$y0['s[y]'] <- sa
-        x.lab <- expression(paste(""^"39","Ar/"^"36","Ar"))
-        y.lab <- expression(paste(""^"40","Ar/"^"36","Ar"))
+        x.lab <- quote(''^39*'Ar/'^36*'Ar')
+        y.lab <- quote(''^40*'Ar/'^36*'Ar')
     }
+    out$displabel <-
+        substitute(a*b*c,list(a='(',b=y.lab,c=')-dispersion = '))
+    out$y0label <- quote('('^40*'Ar/'^36*'Ar)'[o]*' = ')
     out$age[c('t','s[t]')] <-
         get.ArAr.age(R09,sR09,x$J[1],x$J[2],exterr=exterr)
-    out$y0['ci[y]'] <- out$tfact*out$y0['s[y]']
-    out$age['ci[t]'] <- out$tfact*out$age['s[t]']
+    out <- ci_isochron(out,model=model,alpha=alpha)
     if (model==1){
-        out$y0['disp[y]'] <- sqrt(out$mswd)*out$y0['ci[y]']
         out$age['disp[t]'] <-
-            out$tfact*get.ArAr.age(R09,sqrt(out$mswd)*sR09,
-                                   x$J[1],x$J[2],exterr=exterr)[2]
+            out$fact*get.ArAr.age(R09,sqrt(out$mswd)*sR09,
+                                  x$J[1],x$J[2],exterr=exterr)[2]
     }
     if (plot) {
-        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
-                    clabel=clabel,ellipse.col=ellipse.col,a=fit$a[1],
-                    b=fit$b[1],line.col=line.col,lwd=lwd,...)
+                    clabel=clabel,ellipse.col=ellipse.col,
+                    fit=out,ci.col=ci.col,line.col=line.col,lwd=lwd,...)
         graphics::title(isochrontitle(out,sigdig=sigdig,type='Ar-Ar'),
                         xlab=x.lab,ylab=y.lab)
     }
@@ -410,38 +411,37 @@ isochron.ArAr <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
 isochron.PbPb <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
-                          inverse=TRUE,line.col='red',lwd=2,plot=TRUE,
-                          exterr=TRUE,model=1,...){
-    d <- data2york(x,inverse=inverse)
-    fit <- regression(d,model=model)
-    out <- isochron_init(fit,alpha=alpha)
+                          inverse=TRUE,ci.col='gray80',line.col='black',
+                          lwd=1,plot=TRUE,exterr=TRUE,model=1,...){
+    out <- isochron_init(x,model=model,inverse=inverse,alpha=alpha)
     if (inverse){
-        R76 <- fit$a
-        out$y0[c('y','s[y]')] <- fit$b
-        x.lab <- expression(paste(""^"204","Pb/"^"206","Pb"))
-        y.lab <- expression(paste(""^"207","Pb/"^"206","Pb"))
+        R76 <- out$a
+        out$y0[c('y','s[y]')] <- out$b
+        x.lab <- quote(''^204*'Pb/'^206*'Pb')
+        y.lab <- quote(''^207*'Pb/'^206*'Pb')
     } else {
-        R76 <- fit$b
-        out$y0[c('y','s[y]')] <- fit$a
-        x.lab <- expression(paste(""^"206","Pb/"^"204","Pb"))
-        y.lab <- expression(paste(""^"207","Pb/"^"204","Pb"))
+        R76 <- out$b
+        out$y0[c('y','s[y]')] <- out$a
+        x.lab <- quote(''^206*'Pb/'^204*'Pb')
+        y.lab <- quote(''^207*'Pb/'^204*'Pb')
     }
+    out$displabel <-
+        substitute(a*b*c,list(a='(',b=y.lab,c=')-dispersion = '))
+    out$y0label <- quote('('^207*'Pb/'^204*'Pb)'[o]*' = ')
     out$age[c('t','s[t]')] <-
         get.Pb207Pb206.age(R76[1],R76[2],exterr=exterr)
-    out$y0['ci[y]'] <- out$tfact*out$y0['s[y]']
-    out$age['ci[t]'] <- out$tfact*out$age['s[t]']
+    out <- ci_isochron(out,model=model,alpha=alpha)
     if (model==1){
-        out$y0['disp[y]'] <- sqrt(out$mswd)*out$y0['ci[y]']
         out$age['disp[t]'] <-
-            out$tfact*get.Pb207Pb206.age(R76[1],sqrt(out$mswd)*R76[2],
-                                         exterr=exterr)[2]
+            out$fact*get.Pb207Pb206.age(R76[1],sqrt(out$mswd)*R76[2],
+                                        exterr=exterr)[2]
     }
     if (plot) {
-        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
-                    clabel=clabel,ellipse.col=ellipse.col,a=fit$a[1],
-                    b=fit$b[1],line.col=line.col,lwd=lwd,...)
+                    clabel=clabel,ellipse.col=ellipse.col,fit=out,
+                    ci.col=ci.col,line.col=line.col,lwd=lwd,...)
         graphics::title(isochrontitle(out,sigdig=sigdig,type='Pb-Pb'),
                         xlab=x.lab,ylab=y.lab)
     }
@@ -452,12 +452,12 @@ isochron.PbPb <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
 isochron.RbSr <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
-                          line.col='red',lwd=2,plot=TRUE,exterr=TRUE,
-                          model=1,...){
+                          ci.col='gray80',line.col='black',lwd=1,
+                          plot=TRUE,exterr=TRUE,model=1,...){
     isochron_PD(x,'Rb87',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
-                line.col=line.col,lwd=lwd,plot=plot,exterr=exterr,
+                ci.col=ci.col,line.col=line.col,lwd=lwd,plot=plot,exterr=exterr,
                 model=model,...)
 }
 #' @rdname isochron
@@ -465,39 +465,39 @@ isochron.RbSr <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
 isochron.ReOs <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
-                          line.col='red',lwd=2,plot=TRUE,exterr=TRUE,
-                          model=1,...){
+                          ci.col='gray80',line.col='black',lwd=1,
+                          plot=TRUE,exterr=TRUE,model=1,...){
     isochron_PD(x,'Re187',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
-                line.col=line.col,lwd=lwd,plot=plot,exterr=exterr,
-                model=model,...)
+                ci.col=ci.col,line.col=line.col,lwd=lwd,
+                plot=plot,exterr=exterr,model=model,...)
 }
 #' @rdname isochron
 #' @export
 isochron.SmNd <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
-                          line.col='red',lwd=2,plot=TRUE,exterr=TRUE,
-                          model=1,...){
+                          ci.col='gray80',line.col='black',lwd=1,
+                          plot=TRUE,exterr=TRUE,model=1,...){
     isochron_PD(x,'Sm147',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
-                line.col=line.col,lwd=lwd,plot=plot,exterr=exterr,
-                model=model,...)
+                ci.col=ci.col,line.col=line.col,lwd=lwd,
+                plot=plot,exterr=exterr,model=model,...)
 }
 #' @rdname isochron
 #' @export
 isochron.LuHf <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
                           show.numbers=FALSE,levels=NA,clabel="",
                           ellipse.col=c("#00FF0080","#FF000080"),
-                          line.col='red',lwd=2,plot=TRUE,exterr=TRUE,
-                          model=1,...){
+                          ci.col='gray80',line.col='black',lwd=1,
+                          plot=TRUE,exterr=TRUE,model=1,...){
     isochron_PD(x,'Lu176',xlim=xlim,ylim=ylim,alpha=alpha,
                 sigdig=sigdig,show.numbers=show.numbers,
                 levels=levels,clabel=clabel,ellipse.col=ellipse.col,
-                line.col=line.col,lwd=lwd,plot=plot,exterr=exterr,
-                model=model,...)
+                ci.col=ci.col,line.col=line.col,lwd=lwd,
+                plot=plot,exterr=exterr,model=model,...)
 }
 #' @param type following the classification of
 #' Ludwig and Titterington (1994), one of either:
@@ -522,8 +522,8 @@ isochron.LuHf <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
 isochron.ThU <- function (x,type=2,xlim=NA,ylim=NA,alpha=0.05,
                           sigdig=2,show.numbers=FALSE,levels=NA,
                           clabel="",ellipse.col=c("#00FF0080","#FF000080"),
-                          line.col='red',lwd=2,plot=TRUE,exterr=TRUE,
-                          model=1,...){
+                          ci.col='gray80',line.col='black',lwd=1,
+                          plot=TRUE,exterr=TRUE,model=1,...){
     if (x$format %in% c(1,2)){
         out <- isochron_ThU_3D(x,type=type,model=model,
                                exterr=exterr,alpha=alpha)
@@ -533,13 +533,19 @@ isochron.ThU <- function (x,type=2,xlim=NA,ylim=NA,alpha=0.05,
                                exterr=exterr,alpha=alpha)
         intercept.type <- 'Th-U-2D'
     }
+    if (type %in% c(1,3)){
+        out$displabel <- quote('('^234*'U/'^232*'Th)-dispersion = ')
+    } else if (type %in% c(2,4)){
+        out$displabel <- quote('('^234*'U/'^238*'U)-dispersion = ')
+    }
     if (plot){
         scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
-                    clabel=clabel,ellipse.col=ellipse.col,a=out$a[1],
-                    b=out$b[1],line.col=line.col,lwd=lwd,...)
-        graphics::title(isochrontitle(out,sigdig=sigdig,type=intercept.type),
+                    clabel=clabel,ellipse.col=ellipse.col,fit=out,
+                    ci.col=ci.col,line.col=line.col,lwd=lwd,...)
+        graphics::title(isochrontitle(out,sigdig=sigdig,
+                        type=intercept.type,units='ka'),
                         xlab=out$xlab,ylab=out$ylab)
     }
     invisible(out)
@@ -547,23 +553,20 @@ isochron.ThU <- function (x,type=2,xlim=NA,ylim=NA,alpha=0.05,
 #' @rdname isochron
 #' @export
 isochron.UThHe <- function(x,xlim=NA,ylim=NA,alpha=0.05,sigdig=2,
-                           show.numbers=FALSE,line.col='red',lwd=2,
-                           plot=TRUE,model=1,...){
-    d <- data2york(x)
-    fit <- regression(d,model=model)
-    out <- isochron_init(fit,alpha=alpha)
-    out$y0[c('y','s[y]')] <- fit$a
-    out$age[c('t','s[t]')] <- fit$b
-    out$y0['ci[y]'] <- out$tfact*out$y0['s[y]']
-    out$age['ci[t]'] <- out$tfact*out$age['s[t]']
-    if (model==1){
-        out$y0['disp[y]'] <- out$tfact*sqrt(out$mswd)*out$y0['s[y]']
-        out$age['disp[t]'] <- out$tfact*sqrt(out$mswd)*out$age['s[t]']
-    }
+                           show.numbers=FALSE,ci.col='gray80',
+                           line.col='black',lwd=1,plot=TRUE,model=1,...){
+    out <- isochron_init(x,model=model,alpha=alpha)
+    out$y0[c('y','s[y]')] <- out$a
+    out$age[c('t','s[t]')] <- out$b
+    out <- ci_isochron(out,model=model,alpha=alpha)
+    if (model==1)
+        out$age['disp[t]'] <- out$fact*sqrt(out$mswd)*out$age['s[t]']
+    out$displabel <- quote('He-dispersion = ')
+    out$y0label <- quote('He'[o]*' = ')
     if (plot) {
-        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=2*(model!=2),show.numbers=show.numbers,
-                    a=fit$a[1],b=fit$b[1],line.col=line.col,lwd=lwd,...)
+                    fit=out,ci.col=ci.col,line.col=line.col,lwd=lwd,...)
         graphics::title(isochrontitle(out,sigdig=sigdig,type='U-Th-He'),
                         xlab="P",ylab="He")
     }
@@ -579,8 +582,8 @@ isochron_ThU_3D <- function(x,type=2,model=1,
         i48 <- 'b'
         i08 <- 'B'
         id <- c('X','sX','Y','sY','rXY')
-        xlab <- expression(paste(""^"238","U/"^"232","Th"))
-        ylab <- expression(paste(""^"230","Th/"^"232","Th"))
+        x.lab <- quote(''^238*'U/'^232*'Th')
+        y.lab <- quote(''^230*'Th/'^232*'Th')
     } else if (type == 2){
         osmond <- TRUE
         ia <- 'A'
@@ -588,8 +591,8 @@ isochron_ThU_3D <- function(x,type=2,model=1,
         i48 <- 'a'
         i08 <- 'A'
         id <- c('X','sX','Z','sZ','rXZ')
-        xlab <- expression(paste(""^"232","Th/"^"238","U"))
-        ylab <- expression(paste(""^"230","Th/"^"238","U"))
+        x.lab <- quote(''^232*'Th/'^238*'U')
+        y.lab <- quote(''^230*'Th/'^238*'U')
     } else if (type == 3){
         osmond <- FALSE
         ia <- 'A'
@@ -597,8 +600,8 @@ isochron_ThU_3D <- function(x,type=2,model=1,
         i48 <- 'b'
         i08 <- 'B'
         id <- c('X','sX','Z','sZ','rXZ')
-        xlab <- expression(paste(""^"238","U/"^"232","Th"))
-        ylab <- expression(paste(""^"234","U/"^"232","Th"))
+        x.lab <- quote(''^238*'U/'^232*'Th')
+        y.lab <- quote(''^234*'U/'^232*'Th')
     } else {
         osmond <- TRUE
         ia <- 'a'
@@ -606,127 +609,131 @@ isochron_ThU_3D <- function(x,type=2,model=1,
         i48 <- 'a'
         i08 <- 'A'
         id <- c('X','sX','Y','sY','rXY')
-        xlab <- expression(paste(""^"232","Th/"^"238","U"))
-        ylab <- expression(paste(""^"234","U/"^"238","U"))
+        x.lab <- quote(''^232*'Th/'^238*'U')
+        y.lab <- quote(''^234*'U/'^238*'U')
     }
-    d <- data2tit(x,osmond=osmond)
-    fit <- regression(d,model=model,type="titterington")
-    out <- isochron_init(fit,alpha=alpha)
-    out$a <- c(fit$par[ia],sqrt(fit$cov[ia,ia]))
-    out$b <- c(fit$par[ib],sqrt(fit$cov[ib,ib]))
-    out$cov.ab <- fit$cov[ia,ib]
-    tst <- get.ThU.age(fit$par[i08],sqrt(fit$cov[i08,i08]),
-                       fit$par[i48],sqrt(fit$cov[i48,i48]),
-                       fit$cov[i48,i08],exterr=exterr)
+    out <- isochron_init(x,model=model,alpha=alpha,osmond=osmond)
+    out$a <- c(out$par[ia],sqrt(out$cov[ia,ia]))
+    out$b <- c(out$par[ib],sqrt(out$cov[ib,ib]))
+    out$cov.ab <- out$cov[ia,ib]
+    tst <- get.ThU.age(out$par[i08],sqrt(out$cov[i08,i08]),
+                       out$par[i48],sqrt(out$cov[i48,i48]),
+                       out$cov[i48,i08],exterr=exterr)
     out$age['t'] <- tst['t']
     out$y0['y'] <- tst['48_0']
     out$age['s[t]'] <- tst['s[t]']
     out$y0['s[y]'] <- tst['s[48_0]']
-    out$age['ci[t]'] <- out$tfact*out$age['s[t]']
-    out$y0['ci[y]'] <- out$tfact*out$y0['s[y]']
-    if (model==1 && fit$mswd>1){
-        tdispt <- get.ThU.age(fit$par[i08],
-                              sqrt(out$mswd)*sqrt(fit$cov[i08,i08]),
-                              fit$par[i48],
-                              sqrt(out$mswd)*sqrt(fit$cov[i48,i48]),
-                              out$mswd*fit$cov[i48,i08],
+    out$y0label <- quote('('^234*'U/'^238*'U)'[o]*'=')
+    out <- ci_isochron(out,model=model,alpha=alpha,disp=FALSE)
+    if (model==1 && out$mswd>1){
+        tdispt <- get.ThU.age(out$par[i08],
+                              sqrt(out$mswd)*sqrt(out$cov[i08,i08]),
+                              out$par[i48],
+                              sqrt(out$mswd)*sqrt(out$cov[i48,i48]),
+                              out$mswd*out$cov[i48,i08],
                               exterr=exterr)
-        out$age['disp[t]'] <- out$tfact*tdispt['s[t]']
-        out$y0['disp[y]'] <- out$tfact*tdispt['s[48_0]']
+        out$age['disp[t]'] <- out$fact*tdispt['s[t]']
+        out$y0['disp[y]'] <- out$fact*tdispt['s[48_0]']
     }
-    out$xlab <- xlab
-    out$ylab <- ylab
-    out$d <- subset(d,select=id)
+    out$xlab <- x.lab
+    out$ylab <- y.lab
+    out$d <- subset(out$d,select=id)
     out
 }
 isochron_ThU_2D <- function(x,type=2,model=1,
                             exterr=TRUE,alpha=0.05){
-    d <- data2york(x,type=type)
-    fit <- regression(d,model=model,type="york")
+    out <- isochron_init(x,model=model,type=type,alpha=alpha)
     if (type==1){
-        Th230U238 <- fit$b
-        Th230Th232 <- fit$a
-        xlab <- expression(paste(""^"238","U/"^"232","Th"))
-        ylab <- expression(paste(""^"230","Th/"^"232","Th"))
+        Th230U238 <- out$b
+        Th230Th232 <- out$a
+        x.lab <- quote(''^238*'U/'^232*'Th')
+        y.lab <- quote(''^230*'Th/'^232*'Th')
     } else if (type==2) {
-        Th230U238 <- fit$a
-        Th230Th232 <- fit$b
-        xlab <- expression(paste(""^"232","Th/"^"238","U"))
-        ylab <- expression(paste(""^"230","Th/"^"238","U"))
+        Th230U238 <- out$a
+        Th230Th232 <- out$b
+        x.lab <- quote(''^232*'Th/'^238*'U')
+        y.lab <- quote(''^230*'Th/'^238*'U')
     }
-    out <- isochron_init(fit,alpha=alpha)
     out$age[c('t','s[t]')] <-
         get.ThU.age(Th230U238[1],Th230U238[2],
                     exterr=exterr)[c('t','s[t]')]
     out$y0[c('y','s[y]')] <-
         get.Th230Th232_0x(out$age['t'],Th230Th232[1],Th230Th232[2])
-    out$age['ci[t]'] <-
-        out$tfact*out$age['s[t]']
-    out$y0['ci[y]'] <-
-        out$tfact*out$y0['s[y]']
+    out <- ci_isochron(out,model=model,alpha=alpha,disp=FALSE)
     if (model==1 && out$mswd>1){
         out$age['disp[t]'] <-
-            out$tfact*get.ThU.age(Th230U238[1],
+            out$fact*get.ThU.age(Th230U238[1],
                                   sqrt(out$mswd)*Th230U238[2],
                                   exterr=exterr)['s[t]']
         out$y0['disp[y]'] <-
-            out$tfact*get.Th230Th232_0x(out$age['t'],Th230Th232[1],
+            out$fact*get.Th230Th232_0x(out$age['t'],Th230Th232[1],
                                         sqrt(out$mswd)*Th230Th232[2])[2]
     }
-    out$xlab <- xlab
-    out$ylab <- ylab
-    out$d <- d
+    out$xlab <- x.lab
+    out$ylab <- y.lab
     out
 }
 
 isochron_PD <- function(x,nuclide,xlim=NA,ylim=NA,alpha=0.05,
                         sigdig=2,show.numbers=FALSE,levels=NA,
                         clabel="",ellipse.col=c("#00FF0080","#FF000080"),
-                        line.col='red',lwd=2,plot=TRUE,exterr=TRUE,
-                        model=1,...){
-    if (identical(nuclide,'Sm147')){
-        x.lab <- expression(paste(""^"147","Sm/"^"144","Nd"))
-        y.lab <- expression(paste(""^"143","Nd/"^"144","Nd"))
-    } else if (identical(nuclide,'Re187')){
-        x.lab <- expression(paste(""^"187","Re/"^"188","Os"))
-        y.lab <- expression(paste(""^"187","Os/"^"188","Os"))
-    } else if (identical(nuclide,'Rb87')){
-        x.lab <- expression(paste(""^"87","Rb/"^"86","Sr"))
-        y.lab <- expression(paste(""^"87","Sr/"^"86","Sr"))
-    } else if (identical(nuclide,'Lu176')){
-        x.lab <- expression(paste(""^"176","Lu/"^"177","Hf"))
-        y.lab <- expression(paste(""^"176","Hf/"^"177","Hf"))
-    }
-    d <- data2york(x,exterr=exterr,common=FALSE)
-    fit <- regression(d,model=model)
-    out <- isochron_init(fit,alpha=alpha)
-    out$y0[c('y','s[y]')] <- fit$a
-    out$age[c('t','s[t]')] <- get.PD.age(fit$b['b'],
-                   fit$b['s[b]'],nuclide,exterr=exterr)
-    out$y0['ci[y]'] <- out$tfact*out$y0['s[y]']
-    out$age['ci[t]'] <- out$tfact*out$age['s[t]']
+                        ci.col='gray80',line.col='black',lwd=1,
+                        plot=TRUE,exterr=TRUE,model=1,...){
+    out <- isochron_init(x,model=model,exterr=exterr,alpha=alpha)
+    out$y0[c('y','s[y]')] <- out$a
+    out$age[c('t','s[t]')] <- get.PD.age(out$b['b'],out$b['s[b]'],
+                                         nuclide,exterr=exterr)
+    out <- ci_isochron(out,model=model,alpha=alpha)
     if (model==1){
-        out$y0['disp[y]'] <- out$tfact*sqrt(out$mswd)*out$y0['s[y]']
-        out$age['disp[t]'] <- out$tfact*get.PD.age(fit$b['b'],
-                              sqrt(out$mswd)*fit$b['s[b]'],
-                              nuclide,exterr=exterr)[2]
+        out$age['disp[t]'] <- out$fact*get.PD.age(out$b['b'],
+                              sqrt(out$mswd)*out$b['s[b]'],
+                              nuclide,exterr=exterr)[2]        
     }
+    if (identical(nuclide,'Sm147')){
+        x.lab <- quote(''^147*'Sm/'^144*'Nd')
+        y.lab <- quote(''^143*'Sm/'^144*'Nd')
+    } else if (identical(nuclide,'Re187')){
+        x.lab <- quote(''^187*'Re/'^188*'Os')
+        y.lab <- quote(''^187*'Os/'^188*'Os')
+    } else if (identical(nuclide,'Rb87')){
+        x.lab <- quote(''^87*'Rb/'^86*'Sr')
+        y.lab <- quote(''^87*'Sr/'^86*'Sr')
+    } else if (identical(nuclide,'Lu176')){
+        x.lab <- quote(''^176*'Lu/'^177*'Hf')
+        y.lab <- quote(''^176*'Lu/'^177*'Hf')
+    }
+    out$displabel <-
+        substitute(a*b*c,list(a='(',b=y.lab,c=')-dispersion = '))
+    out$y0label <-
+        substitute(a*b*c,list(a='(',b=y.lab,c=quote(')'[o]*' = ')))
     if (plot){
-        scatterplot(d,xlim=xlim,ylim=ylim,alpha=alpha,
+        scatterplot(out$d,xlim=xlim,ylim=ylim,alpha=alpha,
                     show.ellipses=1*(model!=2),
                     show.numbers=show.numbers,levels=levels,
-                    clabel=clabel,ellipse.col=ellipse.col,a=fit$a[1],
-                    b=fit$b[1],line.col=line.col,lwd=lwd,...)
+                    clabel=clabel,ellipse.col=ellipse.col,fit=out,
+                    ci.col=ci.col,line.col=line.col,lwd=lwd,...)
         graphics::title(isochrontitle(out,sigdig=sigdig,type='PD'),
                         xlab=x.lab,ylab=y.lab)
     }
     invisible(out)
 }
 
-isochron_init <- function(fit,alpha=0.05){
-    out <- fit
-    out$tfact <- stats::qt(1-alpha/2,out$df)
-    if (fit$model==1){
+isochron_init <- function(x,model=1,inverse=FALSE,alpha=0.05,
+                          osmond=NA,type=2,exterr=TRUE){
+    if (hasClass(x,'ThU') & !is.na(osmond)){ # 3D regression 
+        d <- data2tit(x,osmond=osmond)
+        out <- regression(d,model=model,type="titterington")
+    } else if (hasClass(x,'ThU') & is.na(osmond)){ # 2D regression
+        d <- data2york(x,type=type)
+        out <- regression(d,model=model,type="york")
+    } else if (hasClass(x,'PD')){
+        d <- data2york(x,exterr=exterr,common=FALSE)
+        out <- regression(d,model=model)
+    } else {
+        d <- data2york(x,inverse=inverse)
+        out <- regression(d,model=model)
+    }
+    if (model==1){
         out$age <- rep(NA,4)
         out$y0 <- rep(NA,4)
         names(out$age) <- c('t','s[t]','ci[t]','disp[t]')
@@ -737,17 +744,23 @@ isochron_init <- function(fit,alpha=0.05){
         names(out$age) <- c('t','s[t]','ci[t]')
         names(out$y0) <- c('y','s[y]','ci[y]')
     }
-    if (fit$model==3){
-        out$w <- c(fit$w,fit$w*stats::qnorm(1-alpha/2))
-        names(out$w) <- c('s','ci')
+    if (out$model < 3){
+        out$fact <- tfact(alpha,out$df)
+    } else {
+        out$fact <- nfact(alpha)
+        out$w <- c(out$w,NA,NA)
+        names(out$w) <- c('s','ll','ul')
     }
     class(out) <- "isochron"
     out
 }
-regression_init <- function(fit,alpha=0.05){
+regression_init <- function(X,model=model,alpha=0.05){
+    fit <- regression(X,model=model)
     out <- fit
-    out$tfact <- stats::qt(1-alpha/2,out$df)
-    if (fit$model==1){
+    out$n <- length(X)
+    out$displabel <- quote('y-dispersion = ')
+    out$y0label <- quote('y-intercept = ')
+    if (model==1){
         out$a <- rep(NA,4)
         out$b <- rep(NA,4)
         names(out$a) <- c('a','s[a]','ci[a]','disp[a]')
@@ -758,16 +771,20 @@ regression_init <- function(fit,alpha=0.05){
         names(out$a) <- c('a','s[a]','ci[a]')
         names(out$b) <- c('b','s[b]','ci[b]')
     }
+    if (out$model < 3){
+        out$fact <- tfact(alpha,out$df)
+    } else {
+        out$fact <- nfact(alpha)
+        out$w <- c(out$w,NA,NA)
+        names(out$w) <- c('s','ll','ul')
+    }
     out$a[c('a','s[a]')] <- fit$a[c('a','s[a]')]
     out$b[c('b','s[b]')] <- fit$b[c('b','s[b]')]
-    out$a['ci[a]'] <- out$tfact*fit$a['s[a]']
-    out$b['ci[b]'] <- out$tfact*fit$b['s[b]']
-    if (fit$model==1){
-        out$a['disp[a]'] <- out$tfact*sqrt(fit$mswd)*fit$a['s[a]']
-        out$b['disp[b]'] <- out$tfact*sqrt(fit$mswd)*fit$b['s[b]']
-    } else if (fit$model==3){
-        out$w <- c(fit$w,stats::qnorm(1-alpha/2))
-        names(out$w) <- c('s','ci')
+    out$a['ci[a]'] <- out$fact*out$a['s[a]']
+    out$b['ci[b]'] <- out$fact*out$b['s[b]']
+    if (out$model==1){
+        out$a['disp[a]'] <- out$fact*sqrt(out$mswd)*out$a['s[a]']
+        out$b['disp[b]'] <- out$fact*sqrt(out$mswd)*out$b['s[b]']
     }
     class(out) <- "isochron"
     out
@@ -779,20 +796,37 @@ get.limits <- function(X,sX){
     c(minx,maxx)
 }
 
-isochrontitle <- function(fit,sigdig=2,type=NA){
-    if (fit$model==1 && fit$mswd>1) args <- quote(a%+-%b~'|'~c~'|'~d)
-    else args <- quote(a%+-%b~'|'~c)
+plot_isochron_line <- function(fit,x,ci.col='gray80',...){
+    y <- fit$a[1]+fit$b[1]*x
+    e <- fit$fact*sqrt(fit$a[2]^2 + 2*x*fit$cov.ab + (fit$b[2]*x)^2)
+    cix <- c(x,rev(x))
+    ciy <- c(y+e,rev(y-e))
+    graphics::polygon(cix,ciy,col=ci.col,border=NA)
+    graphics::lines(x,y,...)
+}
+
+isochrontitle <- function(fit,sigdig=2,type=NA,units="Ma"){
+    if (fit$model==1 && fit$mswd>1){
+        args1 <- quote(a%+-%b~'|'~c~'|'~d~u~'(n='~n~')')
+        args2 <- quote(a%+-%b~'|'~c~'|'~d~u)
+    } else {
+        args1 <- quote(a%+-%b~'|'~c~u~'(n='~n~')')
+        args2 <- quote(a%+-%b~'|'~c~u)
+    }
     if (is.na(type)){
         intercept <- roundit(fit$a[1],fit$a[2:4],sigdig=sigdig)
         slope <- roundit(fit$b[1],fit$b[2:4],sigdig=sigdig)
-        expr1 <- quote('slope =')
-        expr2 <- quote('intercept =')
+        expr1 <- 'slope ='
+        expr2 <- 'intercept ='
         list1 <- list(a=slope[1],
                       b=slope[2],
-                      c=slope[3])
+                      c=slope[3],
+                      u='',
+                      n=fit$n)
         list2 <- list(a=intercept[1],
                       b=intercept[2],
-                      c=intercept[3])
+                      c=intercept[3],
+                      u='')
         if (fit$model==1 && fit$mswd>1){
             list1$d <- slope[4]
             list2$d <- intercept[4]
@@ -800,31 +834,24 @@ isochrontitle <- function(fit,sigdig=2,type=NA){
     } else {
         rounded.age <- roundit(fit$age[1],fit$age[2:4],sigdig=sigdig)
         rounded.intercept <- roundit(fit$y0[1],fit$y0[2:4],sigdig=sigdig)
-        expr1 <- quote('age =')
+        expr1 <- 'age ='
         list1 <- list(a=rounded.age[1],
                       b=rounded.age[2],
-                      c=rounded.age[3])
+                      c=rounded.age[3],
+                      u=units,
+                      n=fit$n)
         list2 <- list(a=rounded.intercept[1],
                       b=rounded.intercept[2],
-                      c=rounded.intercept[3])
+                      c=rounded.intercept[3],
+                      u='')
         if (fit$model==1 && fit$mswd>1){
             list1$d <- rounded.age[4]
             list2$d <- rounded.intercept[4]
         }
-        if (identical(type,'Ar-Ar')){
-            expr2 <- quote('('^40*'Ar/'^36*'Ar)'[o]~'=')
-        } else if (identical(type,'Pb-Pb')) {
-            expr2 <- quote('('^207*'Pb/'^204*'Pb)'[o]~'=')
-        } else if (identical(type,'Th-U-3D')) {
-            expr2 <- quote('('^234*'U/'^238*'U)'[o]~'=')
-        } else if (identical(type,'Th-U-2D')) {
-            expr2 <- quote('('^230*'Th/'^232*'Th)'[o]^x*~'=')
-        } else {
-            expr2 <- quote('y-intercept =')
-        }
+        expr2 <- fit$y0label
     }
-    call1 <- substitute(e~a,list(e=expr1,a=args))
-    call2 <- substitute(e~a,list(e=expr2,a=args))
+    call1 <- substitute(e~a,list(e=expr1,a=args1))
+    call2 <- substitute(e~a,list(e=expr2,a=args2))
     line1 <- do.call(substitute,list(eval(call1),list1))
     line2 <- do.call(substitute,list(eval(call2),list2))
     if (fit$model==1){
@@ -838,10 +865,10 @@ isochrontitle <- function(fit,sigdig=2,type=NA){
         graphics::mtext(line1,line=1)
         graphics::mtext(line2,line=0)
     } else if (fit$model==3){
-        rounded.disp <- signif(fit$w,sigdig)
-        list3 <- list(a=rounded.disp[1],b=rounded.disp[2])
-        expr3 <- quote('y-dispersion =')
-        args3 <- quote(a~'|'~b)
+        rounded.disp <- roundit(fit$w[1],fit$w[2:3],sigdig=sigdig)
+        list3 <- list(a=rounded.disp[1],c=rounded.disp[2],b=rounded.disp[3])
+        args3 <- quote(a+b/-c)
+        expr3 <- fit$displabel
         call3 <- substitute(e~a,list(e=expr3,a=args3))
         line3 <- do.call(substitute,list(eval(call3),list3))
         graphics::mtext(line1,line=2)
