@@ -10,18 +10,18 @@ length.fissiontracks <- function(x){ length(x$Ns) }
 length.UThHe <- function(x){ nrow(x) }
 
 roundit <- function(age,err,sigdig=2){
-    if (length(age)==1){
-        min.err <- min(err,na.rm=TRUE)
-        dat <- c(age,err)
-    } else {
-        min.err <- err
-        dat <- cbind(age,err)
-    }
+    if (length(age)==1) dat <- c(age,err)
+    else dat <- cbind(age,err)
+    min.err <- min(abs(dat),na.rm=TRUE)
     if (is.na(sigdig)) {
         out <- dat
     } else {
-        nd <- log10(trunc(abs(dat)/min.err))+sigdig
-        out <- signif(dat,nd)
+        nd <- ceiling(log10(abs(dat)))-ceiling(log10(min.err))+sigdig
+        rounded <- signif(dat,nd)
+        decimals <- trunc(log10(min.err))+1-sigdig
+        if (decimals<0) nsmall <- abs(decimals)
+        else nsmall <- 0
+        out <- format(rounded,nsmall=nsmall,trim=TRUE)
     }
     out
 }
@@ -84,6 +84,90 @@ get.cor.mult <- function(A,err.A,B,err.B,AB,err.AB){
     get.cov.mult(A,err.A,B,err.B,AB,err.AB)/(err.A*err.B)
 }
 
+# Implements Equations 6 & 7 of Ludwig (1998)
+# x is an [n x 5] matrix with columns X, sX, Y, sY, rhoXY
+wtdmean2D <- function(x){
+    ns <- nrow(x)
+    X <- x[,1]
+    Y <- x[,3]
+    O11 <- rep(0,ns)
+    O22 <- rep(0,ns)
+    O12 <- rep(0,ns)
+    for (i in 1:ns){
+        E <- cor2cov2(x[i,2],x[i,4],x[i,5])
+        O <- solve(E)
+        O11[i] <- O[1,1]
+        O22[i] <- O[2,2]
+        O12[i] <- O[1,2]
+    }
+    numx <- sum(O22)*sum(X*O11+Y*O12)-sum(O12)*sum(Y*O22+X*O12)
+    den <- sum(O11)*sum(O22)-sum(O12)^2
+    numy <- sum(O11)*sum(Y*O22+X*O12)-sum(O12)*sum(X*O11+Y*O12)
+    xbar <- numx/den
+    ybar <- numy/den
+    out <- list()
+    out$x <- c(xbar,ybar)
+    Obar <- matrix(0,2,2)
+    Obar[1,1] <- sum(O11)
+    Obar[2,2] <- sum(O22)
+    Obar[1,2] <- sum(O12)
+    Obar[2,1] <- Obar[1,2]
+    out$cov <- solve(Obar)
+    out
+}
+# generalisation of wtdmean2D to 3 dimensions
+wtdmean3D <- function(x){
+    ns <- nrow(x)
+    X <- x[,1]
+    Y <- x[,3]
+    Z <- x[,5]
+    O11 <- rep(0,ns)
+    O22 <- rep(0,ns)
+    O33 <- rep(0,ns)
+    O12 <- rep(0,ns)
+    O13 <- rep(0,ns)
+    O23 <- rep(0,ns)
+    for (i in 1:ns){
+        E <- cor2cov3(x[i,2],x[i,4],x[i,6],x[i,7],x[i,8],x[i,9])
+        O <- solve(E)
+        O11[i] <- O[1,1]
+        O22[i] <- O[2,2]
+        O33[i] <- O[3,3]
+        O12[i] <- O[1,2]
+        O13[i] <- O[1,3]
+        O23[i] <- O[2,3]
+    }
+    AA <- sum(X*O11+Y*O12+Z*O13)
+    BB <- sum(X*O12+Y*O22+Z*O23)
+    CC <- sum(X*O13+Y*O23+Z*O33)
+    DD <- sum(O22)*sum(O11)-sum(O12)^2
+    EE <- BB*sum(O11)-AA*sum(O12)
+    FF <- sum(O13)*sum(O12)-sum(O23)*sum(O11)
+    GG <- EE/DD
+    HH <- FF/DD
+    II <- (AA-GG*sum(O12))/sum(O11)
+    JJ <- (HH*sum(O12)+sum(O13))/sum(O11)
+    KK <- CC-II*sum(O13)-GG*sum(O23)
+    LL <- HH*sum(O23)-JJ*sum(O13)+sum(O33)
+    xbar <- II-JJ*KK/LL
+    ybar <- GG+HH*KK/LL
+    zbar <- KK/LL
+    out <- list()
+    out$x <- c(xbar,ybar,zbar)
+    Obar <- matrix(0,3,3)
+    Obar[1,1] <- sum(O11)
+    Obar[2,2] <- sum(O22)
+    Obar[3,3] <- sum(O33)
+    Obar[1,2] <- sum(O12)
+    Obar[1,3] <- sum(O13)
+    Obar[2,3] <- sum(O23)
+    Obar[2,1] <- Obar[1,2]
+    Obar[3,1] <- Obar[1,3]
+    Obar[3,2] <- Obar[2,3]
+    out$cov <- solve(Obar)
+    out
+}
+
 # simultaneously performs error propagation for multiple samples
 errorprop <- function(J11,J12,J21,J22,E11,E22,E12){
     out <- matrix(0,length(J11),3)
@@ -93,6 +177,9 @@ errorprop <- function(J11,J12,J21,J22,E11,E22,E12){
     out[,'cov'] <- J11*J21*E11 + J12*J21*E12 + J11*J22*E12 + J12*J22*E22
     out
 }
+errorprop1x2 <- function(J1,J2,E11,E22,E12){
+    sqrt(E11*J1^2 + 2*E12*J1*J2 + E22*J2^2)
+}
 
 hasClass <- function(x,classname){
     classname %in% class(x)
@@ -166,3 +253,10 @@ plot_points <- function(x,y,bg='white',show.numbers=FALSE,...){
     if (show.numbers) graphics::text(x,y,1:length(x),cex=cex,...)
     else graphics::points(x,y,bg=bg,pch=pch,cex=cex,...)
 }
+
+nfact <- function(alpha){
+    stats::qnorm(1-alpha/2)
+}
+tfact <- function(alpha,df){
+    stats::qt(1-alpha/2,df=df)
+}
